@@ -19,15 +19,12 @@
  *                                                                         *
  ***************************************************************************/
 
-//Added by qt3to4:
-#include <QLabel>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QGridLayout>
-
 #ifndef STATISTICSVIEW_H
 #define STATISTICSVIEW_H
 
+#include <QLabel>
+#include <QWidget>
+
 class QLabel;
 class QPushButton;
 class QVBoxLayout;
@@ -36,7 +33,6 @@ class QGridLayout;
 
 class StatisticsBarWidget;
 
-#include <qwidget.h>
 
 /*!
   * StatisticsView takes care of the statistics of a test.
@@ -48,8 +44,6 @@ class StatisticsBarWidget;
 
 class StatisticsView : public QFrame
 {
-    Q_OBJECT
-
 public:
     /** constructor */
     explicit StatisticsView(QWidget * parent = 0);
@@ -57,7 +51,6 @@ public:
     /** destructor */
     ~StatisticsView();
 
-public slots:
     /** increment number of correct answers */
     void addCorrect();
 
